@@ -468,6 +468,11 @@ int GRAIL_PUBLIC grail_get_contacts(const struct grail *ge,
 
 #endif
 
+void GRAIL_PUBLIC grail_set_coordinate_transform_callback(struct grail *ge,
+							  utouch_coordinate_transform_cb callback,
+							  void *user_data);
+
+
 #ifdef __cplusplus
 }
 #endif
